==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Text/ts/Text_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../TextDialog/CharacterMapDialog.ui" line="+14"/>
        <source>Character Map</source>
        <translation>Mapa znakov</translation>
    </message>
</context>
<context>
    <name>Text</name>
    <message>
        <location filename="../Text.js" line="+88"/>
        <source>Position</source>
        <translation>Poloha</translation>
    </message>
    <message>
        <location filename="../Text.ui" line="+17"/>
        <source>Contents:</source>
        <translation>Obsah:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Height:</source>
        <translation>Výška:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Angle:</source>
        <translation>Uhol:</translation>
    </message>
    <message>
        <location filename="../TextInit.js" line="+2"/>
        <source>&amp;Text</source>
        <translation>&amp;Text</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw text</source>
        <translation>Vložiť text</translation>
    </message>
</context>
<context>
    <name>TextDialog</name>
    <message>
        <location filename="../TextDialog/TextDialog.js" line="+242"/>
        <source>Default value:</source>
        <translation>Prednastavené:</translation>
    </message>
    <message>
        <location line="+260"/>
        <source>&amp;Undo</source>
        <translation>&amp;Späť</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Redo</source>
        <translation>&amp;Obnoviť</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Cu&amp;t</source>
        <translation>Vys&amp;trihnúť</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopírovať</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Paste</source>
        <translation>&amp;Vložiť</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Bold</source>
        <translation>&amp;Tučné</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Italic</source>
        <translation>Š&amp;ikmé</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Subscript</source>
        <translation>&amp;Dolný index</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Superscript</source>
        <translation>&amp;Horný index</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>&amp;Color...</source>
        <translation>&amp;Farba...</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Special Characters...</source>
        <translation>&amp;Špeciálne Znaky...</translation>
    </message>
    <message>
        <location line="+310"/>
        <source>Others...</source>
        <translation>Ďalšie...</translation>
    </message>
    <message>
        <location line="+131"/>
        <source>Degree</source>
        <translation>Stupne</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus-Minus</source>
        <translation>Plus-Mínus</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Diameter</source>
        <translation>Priemer</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal</source>
        <translation>Takmer rovné</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Multiplication</source>
        <translation>Násobenie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Division</source>
        <translation>Delenie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translation>Delta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pi</source>
        <translation>Pí</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Identity</source>
        <translation>Identita</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Not equal</source>
        <translation>Nerovná sa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ohm</source>
        <translation>Ohm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Omega</source>
        <translation>Omega</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Squared</source>
        <translation>Štvorcový</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cubed</source>
        <translation>Kubický</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No-break space</source>
        <translation>Nezalomiteľná medzera</translation>
    </message>
    <message>
        <location filename="../TextDialog/TextDialog.ui" line="+14"/>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Main Font</source>
        <translation>Nastavenie písma</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Height:</source>
        <translation>Výška:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Text Height in Drawing Units</source>
        <translation>Výška textu vo výkrese</translation>
    </message>
    <message>
        <location line="+18"/>
        <location line="+213"/>
        <source>Bold</source>
        <translation>Tučné</translation>
    </message>
    <message>
        <location line="-206"/>
        <location line="+219"/>
        <source>Italic</source>
        <translation>Šikmé</translation>
    </message>
    <message>
        <location line="-205"/>
        <source>Text fits on one line and has no formatting</source>
        <translation>Text sa zmestí na jeden riadok a nemá formátovanie</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Simple text
(one line, no formatting)</source>
        <translation>Jednoduchý text
(Jeden riadok, bez formátovania)</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Rich Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cut</source>
        <translation>Vystrihnúť</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Copy</source>
        <translation>Kopírovať</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Paste</source>
        <translation>Vložiť</translation>
    </message>
    <message>
        <location line="+115"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Insert Symbol...</source>
        <translation>Vložiť Znak...</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Source</source>
        <translation>Zdrojový text</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Attribute Details</source>
        <translation>Atribút podrobnosti</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tag:</source>
        <translation>Označenie:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Prompt:</source>
        <translation>Poznámka:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Value:</source>
        <translation>Hodnota:</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Text Geometry</source>
        <translation>Konfigurácia textu</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Line spacing factor:</source>
        <translation>Riadkovanie:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Line Spacing Factor</source>
        <translation>Faktor riadkovania</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Angle:</source>
        <translation>Uhol:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Rotation Angle</source>
        <translation>Uhol Natočenia</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Alignment</source>
        <translation>Zarovnanie</translation>
    </message>
    <message>
        <location line="+311"/>
        <source>Bottom Left</source>
        <translation>Vľavo Dole</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Bottom Center</source>
        <translation>V strede Dole</translation>
    </message>
    <message>
        <location line="-261"/>
        <source>Top Center</source>
        <translation>V strede Hore</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Middle Right</source>
        <translation>Vpravo V strede</translation>
    </message>
    <message>
        <location line="+116"/>
        <source>Base Left</source>
        <translation>Základ Vľavo</translation>
    </message>
    <message>
        <location line="-177"/>
        <source>Top Left</source>
        <translation>Vľavo Hore</translation>
    </message>
    <message>
        <location line="+206"/>
        <source>Base Center</source>
        <translation>Základ V strede</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Base Right</source>
        <translation>Základ Vpravo</translation>
    </message>
    <message>
        <location line="-116"/>
        <source>Middle Center</source>
        <translation>Stred Stred</translation>
    </message>
    <message>
        <location line="+203"/>
        <source>Bottom Right</source>
        <translation>Vpravo Dole</translation>
    </message>
    <message>
        <location line="-174"/>
        <source>Middle Left</source>
        <translation>Vľavo V strede</translation>
    </message>
    <message>
        <location line="-58"/>
        <source>Top Right</source>
        <translation>Vpravo Hore</translation>
    </message>
    <message>
        <location line="+291"/>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Text/ts/Text_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../TextDialog/CharacterMapDialog.ui" line="+14"/>
        <source>Character Map</source>
        <translation>Mapa znakov</translation>
    </message>
</context>
<context>
    <name>Text</name>
    <message>
        <location filename="../Text.js" line="+88"/>
        <source>Position</source>
        <translation>Poloha</translation>
    </message>
    <message>
        <location filename="../Text.ui" line="+17"/>
        <source>Contents:</source>
        <translation>Obsah:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Height:</source>
        <translation>Výška:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Angle:</source>
        <translation>Uhol:</translation>
    </message>
    <message>
        <location filename="../TextInit.js" line="+2"/>
        <source>&amp;Text</source>
        <translation>&amp;Text</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw text</source>
        <translation>Vložiť text</translation>
    </message>
</context>
<context>
    <name>TextDialog</name>
    <message>
        <location filename="../TextDialog/TextDialog.js" line="+242"/>
        <source>Default value:</source>
        <translation>Prednastavené:</translation>
    </message>
    <message>
        <location line="+266"/>
        <source>&amp;Undo</source>
        <translation>&amp;Späť</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Redo</source>
        <translation>&amp;Obnoviť</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Cu&amp;t</source>
        <translation>Vys&amp;trihnúť</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopírovať</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Paste</source>
        <translation>&amp;Vložiť</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Bold</source>
        <translation>&amp;Tučné</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Italic</source>
        <translation>Š&amp;ikmé</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Subscript</source>
        <translation>&amp;Dolný index</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Superscript</source>
        <translation>&amp;Horný index</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>&amp;Color...</source>
        <translation>&amp;Farba...</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Special Characters...</source>
        <translation>&amp;Špeciálne Znaky...</translation>
    </message>
    <message>
        <location line="+305"/>
        <source>Others...</source>
        <translation>Ďalšie...</translation>
    </message>
    <message>
        <location line="+131"/>
        <source>Degree</source>
        <translation>Stupne</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus-Minus</source>
        <translation>Plus-Mínus</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Diameter</source>
        <translation>Priemer</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal</source>
        <translation>Takmer rovné</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Multiplication</source>
        <translation>Násobenie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Division</source>
        <translation>Delenie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translation>Delta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pi</source>
        <translation>Pí</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Identity</source>
        <translation>Identita</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Not equal</source>
        <translation>Nerovná sa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ohm</source>
        <translation>Ohm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Omega</source>
        <translation>Omega</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Squared</source>
        <translation>Štvorcový</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cubed</source>
        <translation>Kubický</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No-break space</source>
        <translation>Nezalomiteľná medzera</translation>
    </message>
    <message>
        <location filename="../TextDialog/TextDialog.ui" line="+14"/>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Main Font</source>
        <translation>Nastavenie písma</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Height:</source>
        <translation>Výška:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Text Height in Drawing Units</source>
        <translation>Výška textu vo výkrese</translation>
    </message>
    <message>
        <location line="+18"/>
        <location line="+268"/>
        <source>Bold</source>
        <translation>Tučné</translation>
    </message>
    <message>
        <location line="-261"/>
        <location line="+274"/>
        <source>Italic</source>
        <translation>Šikmé</translation>
    </message>
    <message>
        <location line="-260"/>
        <source>Text fits on one line and has no formatting</source>
        <translation>Text sa zmestí na jeden riadok a nemá formátovanie</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Simple text
(one line, no formatting)</source>
        <translation>Jednoduchý text
(Jeden riadok, bez formátovania)</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Rich Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cut</source>
        <translation>Vystrihnúť</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Copy</source>
        <translation>Kopírovať</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Paste</source>
        <translation>Vložiť</translation>
    </message>
    <message>
        <location line="+170"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Insert Symbol...</source>
        <translation>Vložiť Znak...</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Source</source>
        <translation>Zdrojový text</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Attribute Details</source>
        <translation>Atribút podrobnosti</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tag:</source>
        <translation>Označenie:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Prompt:</source>
        <translation>Názov výzvy:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Value:</source>
        <translation>Hodnota:</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Text Geometry</source>
        <translation>Konfigurácia textu</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Line spacing factor:</source>
        <translation>Riadkovanie:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Line Spacing Factor</source>
        <translation>Faktor riadkovania</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Angle:</source>
        <translation>Uhol:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Rotation Angle</source>
        <translation>Uhol Natočenia</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Alignment</source>
        <translation>Zarovnanie</translation>
    </message>
    <message>
        <location line="+311"/>
        <source>Bottom Left</source>
        <translation>Vľavo Dole</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Bottom Center</source>
        <translation>V strede Dole</translation>
    </message>
    <message>
        <location line="-261"/>
        <source>Top Center</source>
        <translation>V strede Hore</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Middle Right</source>
        <translation>Vpravo V strede</translation>
    </message>
    <message>
        <location line="+116"/>
        <source>Base Left</source>
        <translation>Základ Vľavo</translation>
    </message>
    <message>
        <location line="-177"/>
        <source>Top Left</source>
        <translation>Vľavo Hore</translation>
    </message>
    <message>
        <location line="+206"/>
        <source>Base Center</source>
        <translation>Základ V strede</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Base Right</source>
        <translation>Základ Vpravo</translation>
    </message>
    <message>
        <location line="-116"/>
        <source>Middle Center</source>
        <translation>Stred Stred</translation>
    </message>
    <message>
        <location line="+203"/>
        <source>Bottom Right</source>
        <translation>Vpravo Dole</translation>
    </message>
    <message>
        <location line="-174"/>
        <source>Middle Left</source>
        <translation>Vľavo V strede</translation>
    </message>
    <message>
        <location line="-58"/>
        <source>Top Right</source>
        <translation>Vpravo Hore</translation>
    </message>
    <message>
        <location line="+291"/>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
</TS>
